@@ -4,6 +4,7 @@ from pathlib import Path as _Path
 
 from sphinx.application import Sphinx
 from .extension import backref, directive, SphinxCodeAutoLink
+from .extension.block import clean_pycon  # NOQA
 
 _version_file = _Path(_os.path.realpath(__file__)).parent / "VERSION"
 __version__ = _version_file.read_text().strip()
@@ -14,7 +15,7 @@ def setup(app: Sphinx):
     state = SphinxCodeAutoLink()
     app.setup_extension('sphinx.ext.autodoc')
     app.add_css_file('sphinx-codeautolink.css')
-    app.add_config_value('codeautolink_autodoc_inject', True, 'html', types=[bool])
+    app.add_config_value('codeautolink_autodoc_inject', False, 'html', types=[bool])
     app.add_config_value('codeautolink_global_preface', '', 'html', types=[str])
     app.add_config_value('codeautolink_custom_blocks', {}, 'html', types=[dict])
     app.add_config_value('codeautolink_concat_default', False, 'html', types=[bool])
