@@ -1,6 +1,8 @@
 """Docstring."""
 from typing import Optional
 
+from .sub import subfoo  # NOQA
+
 
 class Baz:
     """Baz test class."""
@@ -16,6 +18,10 @@ class Foo:
     def meth(self) -> Baz:
         """Test method."""
 
+    def selfref(self) -> "Foo":
+        """Return self."""
+        return self
+
 
 def bar() -> Foo:
     """bar test function."""
